@@ -61,6 +61,8 @@ from casadi import (
     vertsplit,
     horzsplit,
     reshape,
+    gradient,
+    hessian,
 )
 
 eye = SX.eye
@@ -107,3 +109,8 @@ def dev(T):
     dim = T.shape[0]
 
     return T - trace(T) / dim * eye(dim)
+
+
+def ddot(A, B):
+
+    return trace(transpose(A) @ B)
