@@ -1,7 +1,7 @@
 import numpy as np
 
 from matadi import Variable, Material, MaterialTensor
-from matadi.math import det, transpose, trace, invariants, sqrt, dev
+from matadi.math import det, transpose, trace, invariants, sqrt, dev, ddot
 
 
 def neohooke(x, mu=1.0, bulk=200.0):
@@ -30,14 +30,14 @@ def test_simple():
         FF[a, a] += 1
 
     # init Material
-    W = Material(x=[F], fun=neohooke, kwargs={"mu": 1.0, "bulk": 10.0},)
+    W = Material(x=[F], fun=neohooke, kwargs={"mu": 1.0, "bulk": 10.0})
 
     W0 = W.function([FF])
     dW = W.gradient([FF])
     DW = W.hessian([FF])
 
     # dW and DW are always lists...
-    assert W0[0].shape == (8, 1000)
+    assert W0[0].shape == (1, 1, 8, 1000)
     assert dW[0].shape == (3, 3, 8, 1000)
     assert DW[0].shape == (3, 3, 3, 3, 8, 1000)
 
@@ -46,10 +46,26 @@ def test_simple():
     dW = W.gradient([FF], threads=2)
     DW = W.hessian([FF], threads=2)
 
-    assert W0[0].shape == (8, 1000)
+    assert W0[0].shape == (1, 1, 8, 1000)
     assert dW[0].shape == (3, 3, 8, 1000)
     assert DW[0].shape == (3, 3, 3, 3, 8, 1000)
 
+    # test single value input
+    W00 = W.function([FF[:, :, 0, 0]])
+
+    assert W00[0].shape == (1, 1)
+
+    # init Material with compress
+    W = Material(x=[F], fun=neohooke, kwargs={"mu": 1.0, "bulk": 10.0}, compress=True)
+    W0 = W.function([FF])
+
+    assert W0[0].shape == (8, 1000)
+
+    # test single value input
+    W00 = W.function([FF[:, :, 0, 0]])
+
+    assert W00[0].shape == (1,)
+
 
 def test_tensor():
 
@@ -67,7 +83,7 @@ def test_tensor():
         FF[a, a] += 1
 
     # init Material
-    for fun in [lambda x: dev(x[0]), lambda x: x]:
+    for fun in [lambda x: dev(x[0]) + ddot(x[0], x[0]), lambda x: x]:
 
         W = MaterialTensor(x=[F], fun=fun)
 
